@@ -4,7 +4,7 @@ mod use_candidate_test;
 use stun::attributes::ATTR_USE_CANDIDATE;
 use stun::message::*;
 
-use util::Error;
+use anyhow::Result;
 
 /// Represents USE-CANDIDATE attribute.
 #[derive(Default)]
@@ -12,7 +12,7 @@ pub struct UseCandidateAttr;
 
 impl Setter for UseCandidateAttr {
     /// Adds USE-CANDIDATE attribute to message.
-    fn add_to(&self, m: &mut Message) -> Result<(), Error> {
+    fn add_to(&self, m: &mut Message) -> Result<()> {
         m.add(ATTR_USE_CANDIDATE, &[]);
         Ok(())
     }
